pub fn load_image_with_limit(
path: &PathBuf,
max_image_bytes: u64,
) -> Result<InputContent, ImageLoadError>Expand description
Load an image file with an explicit maximum byte limit.
pub fn load_image_with_limit(
path: &PathBuf,
max_image_bytes: u64,
) -> Result<InputContent, ImageLoadError>Load an image file with an explicit maximum byte limit.