pub struct ExplicitResourcePaths {
pub extensions: Vec<PathBuf>,
pub packages: Vec<PathBuf>,
pub skills: Vec<PathBuf>,
pub fragments: Vec<PathBuf>,
pub themes: Vec<PathBuf>,
}Expand description
Explicit resource paths from resolved configuration or embedder setup.
Fields
extensions: Vec<PathBuf>packages: Vec<PathBuf>skills: Vec<PathBuf>fragments: Vec<PathBuf>themes: Vec<PathBuf>Trait Implementations
Sourceimpl Clone for ExplicitResourcePaths
impl Clone for ExplicitResourcePaths
Sourcefn clone(&self) -> ExplicitResourcePaths
fn clone(&self) -> ExplicitResourcePaths
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExplicitResourcePaths
impl Debug for ExplicitResourcePaths
Sourceimpl Default for ExplicitResourcePaths
impl Default for ExplicitResourcePaths
Sourcefn default() -> ExplicitResourcePaths
fn default() -> ExplicitResourcePaths
Returns the “default value” for a type. Read more
impl Eq for ExplicitResourcePaths
Sourceimpl PartialEq for ExplicitResourcePaths
impl PartialEq for ExplicitResourcePaths
Sourcefn eq(&self, other: &ExplicitResourcePaths) -> bool
fn eq(&self, other: &ExplicitResourcePaths) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ExplicitResourcePaths