pub struct ResumedSession {
pub header: SessionHeader,
pub entries: Vec<SessionEntry>,
pub path: PathBuf,
pub skipped_entries: usize,
}Expand description
Result of a resume operation.
Fields
header: SessionHeaderentries: Vec<SessionEntry>path: PathBufFilesystem path of the resumed session JSONL file. Used by the harness to open the file in append mode instead of creating a new session.
skipped_entries: usizeNumber of corrupt/unparseable entries skipped during load.