Tool safety policy for non-interactive mode (S8.4, S10).
Also contains tool selection types and resolution for –tools / –no-tools / –no-builtin-tools CLI flags (task 3.8).
Structs
- Tool
Flags - CLI tool flags to be resolved into a
ToolSelection. - Tool
Runtime Config - Resolved tool runtime config used to choose active tools.
Enums
- RunMode
- Application mode used to resolve default active tools.
- Tool
Policy Error - Tool
Selection - Resolved tool selection state driven by CLI flags.
Constants
- BUILTIN_
TOOL_ NAMES - Pi-aligned built-in policy order consumed by the harness after Task 2 wiring.
Functions
- filter_
tool_ names - Filter a list of tool names based on the given selection.
- is_
mutating_ tool - Returns
trueif the tool is considered mutating (write, edit, bash). - resolve_
tool_ selection - Resolve tool flags into a
ToolSelectionwith deterministic precedence: